
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "_as_gen/run_sph_shear_test.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        :ref:`Go to the end <sphx_glr_download__as_gen_run_sph_shear_test.py>`
        to download the full example code.

.. rst-class:: sphx-glr-example-title

.. _sphx_glr__as_gen_run_sph_shear_test.py:


Shearing box in SPH
========================

This simple example shows how to run an unstratified shearing box simulaiton

.. GENERATED FROM PYTHON SOURCE LINES 7-22

.. code-block:: Python
   :lineno-start: 9



    import shamrock

    # If we use the shamrock executable to run this script instead of the python interpreter,
    # we should not initialize the system as the shamrock executable needs to handle specific MPI logic
    if not shamrock.sys.is_initialized():
        shamrock.change_loglevel(1)
        shamrock.sys.init("0:0")

    from math import exp

    import matplotlib.pyplot as plt
    import numpy as np








.. GENERATED FROM PYTHON SOURCE LINES 24-25

Initialize context & attach a SPH model to it

.. GENERATED FROM PYTHON SOURCE LINES 25-31

.. code-block:: Python
   :lineno-start: 25

    ctx = shamrock.Context()
    ctx.pdata_layout_new()

    model = shamrock.get_Model_SPH(context=ctx, vector_type="f64_3", sph_kernel="M4")









.. GENERATED FROM PYTHON SOURCE LINES 32-33

Setup parameters

.. GENERATED FROM PYTHON SOURCE LINES 33-53

.. code-block:: Python
   :lineno-start: 33

    gamma = 5.0 / 3.0
    rho = 1
    uint = 1

    dr = 0.02
    bmin = (-0.6, -0.6, -0.1)
    bmax = (0.6, 0.6, 0.1)
    pmass = -1

    bmin, bmax = model.get_ideal_fcc_box(dr, bmin, bmax)
    xm, ym, zm = bmin
    xM, yM, zM = bmax

    Omega_0 = 1
    eta = 0.00
    q = 3.0 / 2.0

    shear_speed = -q * Omega_0 * (xM - xm)









.. GENERATED FROM PYTHON SOURCE LINES 54-55

Generate the config & init the scheduler

.. GENERATED FROM PYTHON SOURCE LINES 55-73

.. code-block:: Python
   :lineno-start: 55

    cfg = model.gen_default_config()
    # cfg.set_artif_viscosity_Constant(alpha_u = 1, alpha_AV = 1, beta_AV = 2)
    # cfg.set_artif_viscosity_VaryingMM97(alpha_min = 0.1,alpha_max = 1,sigma_decay = 0.1, alpha_u = 1, beta_AV = 2)
    cfg.set_artif_viscosity_VaryingCD10(
        alpha_min=0.0, alpha_max=1, sigma_decay=0.1, alpha_u=1, beta_AV=2
    )
    cfg.set_boundary_shearing_periodic((1, 0, 0), (0, 1, 0), shear_speed)
    cfg.set_eos_adiabatic(gamma)
    cfg.add_ext_force_shearing_box(Omega_0=Omega_0, eta=eta, q=q)
    cfg.set_units(shamrock.UnitSystem())
    cfg.print_status()
    model.set_solver_config(cfg)

    model.init_scheduler(int(1e7), 1)

    model.resize_simulation_box(bmin, bmax)






.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ----- SPH Solver configuration ----- 
    units :  
    unit_length      : 1 
    unit_mass        : 1 
    unit_current     : 1 
    unit_temperature : 1 
    unit_qte         : 1 
    unit_lumint      : 1 
    part mass 0 ( can be changed using .set_part_mass() ) 
    cfl force 0 
    cfl courant 0 
    --- artificial viscosity config 
      Config Type : VaryingCD10 (Cullen & Dehnen 2010) 
      alpha_min   = 0 
      alpha_max   = 1 
      sigma_decay = 0.1 
      alpha_u     = 1 
      beta_AV     = 2 
    --- artificial viscosity config (deduced) 
    ------------- 
    EOS config f64_3 : 
    adiabatic :  
    gamma 1.6666666666666667 
    --- Bondaries config 
      Config Type : ShearingPeriodic (Stone 2010) 
      shear_base   = (1,0,0) 
      shear_dir   = (0,1,0) 
      shear_speed = -1.8000000000000003 
    --- Bondaries config config (deduced) 
    ------------- 
    ------------------------------------ 




.. GENERATED FROM PYTHON SOURCE LINES 74-76

Add the particles & set fields values
Note that every field that are not mentionned are set to zero

.. GENERATED FROM PYTHON SOURCE LINES 76-122

.. code-block:: Python
   :lineno-start: 76

    model.add_cube_fcc_3d(dr, bmin, bmax)

    vol_b = (xM - xm) * (yM - ym) * (zM - zm)

    totmass = rho * vol_b
    # print("Total mass :", totmass)

    pmass = model.total_mass_to_part_mass(totmass)

    model.set_value_in_a_box("uint", "f64", 1, bmin, bmax)
    # model.set_value_in_a_box("vxyz","f64_3", (-10,0,0) , bmin,bmax)

    pen_sz = 0.1

    mm = 1
    MM = 0


    def vel_func(r):
        global mm, MM
        x, y, z = r

        s = (x - (xM + xm) / 2) / (xM - xm)
        vel = (shear_speed) * s

        mm = min(mm, vel)
        MM = max(MM, vel)

        return (0, vel, 0.0)
        # return (1,0,0)


    model.set_field_value_lambda_f64_3("vxyz", vel_func)
    # print("Current part mass :", pmass)
    model.set_particle_mass(pmass)


    tot_u = pmass * model.get_sum("uint", "f64")
    # print("total u :",tot_u)

    print(f"v_shear = {shear_speed} | dv = {MM-mm}")


    model.set_cfl_cour(0.3)
    model.set_cfl_force(0.25)





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    Info: Add fcc lattice size : ( 31 34 6 )                                              [SPH][rank=0] 
    Info: Push particles :                                                              [Model][rank=0]
      rank = 0  patch id=0, add N=6120 particles, coords = (-0.6,-0.6,-0.1) (0.6000000000000002,0.5777945491468365,0.09595917942265422)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.22 us    (22.9%)  
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1453.00 ns (0.4%)
       patch tree reduce : 500.00 ns  (0.1%)
       gen split merge   : 701.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 922.00 ns  (0.2%)
       LB compute        : 394.76 us  (97.8%)
       LB move op cnt    : 0
       LB apply          : 1753.00 ns (0.4%)  
    Info: current particle counts : min =  6120 max =  6120                             [Model][rank=0] 
    v_shear = -1.8000000000000003 | dv = 1.7700000000000002




.. GENERATED FROM PYTHON SOURCE LINES 123-129

.. code-block:: Python
   :lineno-start: 123

    dump_folder = "_to_trash"
    import os

    os.system("mkdir -p " + dump_folder)






.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0



.. GENERATED FROM PYTHON SOURCE LINES 130-131

Perform the plot

.. GENERATED FROM PYTHON SOURCE LINES 131-146

.. code-block:: Python
   :lineno-start: 131

    def plot():
        dic = ctx.collect_data()
        fig, axs = plt.subplots(2, 1, figsize=(5, 8), sharex=True)
        fig.suptitle("t = {:.2f}".format(model.get_time()))
        axs[0].scatter(dic["xyz"][:, 0], dic["xyz"][:, 1], s=1)
        axs[1].scatter(dic["xyz"][:, 0], dic["vxyz"][:, 1], s=1)

        axs[0].set_ylabel("y")
        axs[1].set_ylabel("vy")
        axs[1].set_xlabel("x")

        plt.tight_layout()
        plt.show()









.. GENERATED FROM PYTHON SOURCE LINES 147-148

Performing the timestep loop

.. GENERATED FROM PYTHON SOURCE LINES 148-163

.. code-block:: Python
   :lineno-start: 148

    model.timestep()

    dt_stop = 0.1
    for i in range(2):

        t_target = i * dt_stop
        # skip if the model is already past the target
        if model.get_time() > t_target:
            continue

        model.evolve_until(i * dt_stop)

        # Dump name is "dump_xxxx.sham" where xxxx is the timestep
        model.do_vtk_dump(dump_folder + "/dump_{:04}.vtk".format(i), True)
        plot()



.. rst-class:: sphx-glr-horizontal


    *

      .. image-sg:: /_as_gen/images/sphx_glr_run_sph_shear_test_001.png
         :alt: t = 0.00
         :srcset: /_as_gen/images/sphx_glr_run_sph_shear_test_001.png
         :class: sphx-glr-single-img

    *

      .. image-sg:: /_as_gen/images/sphx_glr_run_sph_shear_test_002.png
         :alt: t = 0.10
         :srcset: /_as_gen/images/sphx_glr_run_sph_shear_test_002.png
         :class: sphx-glr-single-img


.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ---------------- t = 0, dt = 0 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 11.60 us   (1.5%)
       patch tree reduce : 1613.00 ns (0.2%)
       gen split merge   : 1022.00 ns (0.1%)
       split / merge op  : 0/0
       apply split merge : 982.00 ns  (0.1%)
       LB compute        : 759.90 us  (96.6%)
       LB move op cnt    : 0
       LB apply          : 2.10 us    (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1954.00 ns (69.9%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.741503267973856  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.022000000000000002 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.7684640522875816  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.024200000000000003 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.7684640522875816  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.026620000000000005 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.794607843137255  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.029282000000000006 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.8504901960784312  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.03221020000000001 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.320424836601307  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.03543122000000001 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.320424836601307  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.038974342000000016 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4184640522875813  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.8314338416863407e-07, max = 2.831433850588215e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (0,0.004154393760827157,0)
        sum a = (5.594447467541066e-17,1.3411735915250473e-18,0.005082303061895432)
        sum e = 0.3143698998713959
        sum de = 9.604356448640085e-05  
    Info: cfl dt = 0.00011089173088629873 cfl multiplier : 0.01                    [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    2.5423e+04    |        6120 |   2.407e-01   |    6 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0 (tsim/hr)                                             [sph::Model][rank=0] 
    Info: iteration since start : 1                                                       [SPH][rank=0] 
    Info: time since start : 8.074666749 (s)                                              [SPH][rank=0] 
    Info: dump to _to_trash/dump_0000.vtk                                            [VTK Dump][rank=0]
                  - took 5.35 ms, bandwidth = 91.72 MB/s  
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed
    ---------------- t = 0, dt = 0.00011089173088629873 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.30 us    (1.5%)
       patch tree reduce : 862.00 ns  (0.2%)
       gen split merge   : 801.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 911.00 ns  (0.2%)
       LB compute        : 405.29 us  (96.0%)
       LB move op cnt    : 0
       LB apply          : 1924.00 ns (0.5%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1763.00 ns (66.7%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4470588235294115  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.5839830969886152e-09, max = 3.408253654510689e-09
      iterations = 0  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (6.203777486236894e-21,-4.3007972628265963e-17,5.635853834223204e-07)
        sum a = (5.231785487486977e-17,1.3229948647768492e-18,0.0050823030306469666)
        sum e = 0.31436991054897867
        sum de = 9.744668853644791e-05  
    Info: cfl dt = 0.0037703106533756884 cfl multiplier : 0.34                     [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    7.4974e+04    |        6120 |   8.163e-02   |   34 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 4.890603437472897 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.00011089173088629873, dt = 0.0037703106533756884 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1904.00 ns (0.6%)
       patch tree reduce : 561.00 ns  (0.2%)
       gen split merge   : 391.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 481.00 ns  (0.1%)
       LB compute        : 316.17 us  (97.7%)
       LB move op cnt    : 0
       LB apply          : 1051.00 ns (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1813.00 ns (71.5%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4388888888888887  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 7.172685023217074e-12, max = 3.3201651540132534e-11
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (2.0325728281798964e-19,3.778270492576636e-18,1.9725446641821525e-05)
        sum a = (6.397365274293921e-17,-6.787525031824126e-18,0.005082264782670167)
        sum e = 0.3143702833343977
        sum de = 0.00013824059786473963  
    Info: cfl dt = 0.006209449394346196 cfl multiplier : 0.56                      [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.0923e+05    |        6120 |   5.603e-02   |   24 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 242.25120769201075 (tsim/hr)                            [sph::Model][rank=0] 
    ---------------- t = 0.003881202384261987, dt = 0.006209449394346196 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1813.00 ns (0.6%)
       patch tree reduce : 381.00 ns  (0.1%)
       gen split merge   : 411.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 481.00 ns  (0.1%)
       LB compute        : 315.78 us  (97.9%)
       LB move op cnt    : 0
       LB apply          : 882.00 ns  (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1694.00 ns (67.9%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4367647058823527  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.3294096404573666e-10, max = 1.0880275964821347e-09
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (6.224711283709493e-19,-8.32023395705706e-18,5.128344051510259e-05)
        sum a = (5.25651254242741e-17,-3.3428249753164246e-20,0.005082044319848335)
        sum e = 0.3143712315922659
        sum de = 0.00020394600495906779  
    Info: cfl dt = 0.00783459684767434 cfl multiplier : 0.7066666666666667         [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.0923e+05    |        6120 |   5.603e-02   |   24 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 398.98266853521744 (tsim/hr)                            [sph::Model][rank=0] 
    ---------------- t = 0.010090651778608184, dt = 0.00783459684767434 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1903.00 ns (0.6%)
       patch tree reduce : 401.00 ns  (0.1%)
       gen split merge   : 431.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 391.00 ns  (0.1%)
       LB compute        : 320.46 us  (97.9%)
       LB move op cnt    : 0
       LB apply          : 911.00 ns  (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1653.00 ns (71.4%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4455882352941174  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.3550983973723722e-09, max = 6.545525037921152e-09
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.98905088561951e-19,-1.9011935563710095e-17,9.109852444675985e-05)
        sum a = (4.523687588261345e-17,2.304925168581382e-18,0.0050814865698827275)
        sum e = 0.3143730498982785
        sum de = 0.00028163943820289474  
    Info: cfl dt = 0.008916682434912383 cfl multiplier : 0.8044444444444444        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1251e+05    |        6120 |   5.440e-02   |   25 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 518.5009285484106 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.017925248626282524, dt = 0.008916682434912383 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1834.00 ns (0.6%)
       patch tree reduce : 350.00 ns  (0.1%)
       gen split merge   : 401.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 400.00 ns  (0.1%)
       LB compute        : 294.65 us  (97.8%)
       LB move op cnt    : 0
       LB apply          : 811.00 ns  (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1663.00 ns (67.8%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4475490196078429  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 3.615264058360426e-09, max = 1.8821916322165856e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (1.3738210882704364e-18,-1.3143557990133617e-17,0.00013640634161461517)
        sum a = (7.034830662981827e-17,5.085529473676747e-19,0.005080472285302091)
        sum e = 0.31437589351354017
        sum de = 0.00036085682195507605  
    Info: cfl dt = 0.009636396780122314 cfl multiplier : 0.8696296296296296        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1025e+05    |        6120 |   5.551e-02   |   25 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 578.2647276413 (tsim/hr)                                [sph::Model][rank=0] 
    ---------------- t = 0.026841931061194906, dt = 0.009636396780122314 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1743.00 ns (0.6%)
       patch tree reduce : 492.00 ns  (0.2%)
       gen split merge   : 411.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 411.00 ns  (0.1%)
       LB compute        : 292.25 us  (97.7%)
       LB move op cnt    : 0
       LB apply          : 802.00 ns  (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1613.00 ns (72.5%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4460784313725488  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 5.752376507485498e-09, max = 3.4459765836674773e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (2.163852361168645e-18,-2.9341887867882385e-18,0.00018535926635944897)
        sum a = (3.9036266744779485e-17,9.514917308869544e-18,0.00507892197655579)
        sum e = 0.3143797778012691
        sum de = 0.00043296546533910536  
    Info: cfl dt = 0.010114315298959963 cfl multiplier : 0.9130864197530864        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    8.1617e+04    |        6120 |   7.498e-02   |   31 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 462.64555810671055 (tsim/hr)                            [sph::Model][rank=0] 
    ---------------- t = 0.03647832784131722, dt = 0.010114315298959963 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.07 us    (0.2%)
       patch tree reduce : 642.00 ns  (0.1%)
       gen split merge   : 421.00 ns  (0.0%)
       split / merge op  : 0/0
       apply split merge : 671.00 ns  (0.1%)
       LB compute        : 894.51 us  (99.1%)
       LB move op cnt    : 0
       LB apply          : 1022.00 ns (0.1%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1973.00 ns (75.2%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4460784313725488  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 5.818251260610762e-09, max = 4.4864233628056496e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (2.4088554762683813e-18,-3.215549355384371e-17,0.0002367216149140455)
        sum a = (2.5983146080266055e-17,6.463835138532299e-18,0.005076787484773816)
        sum e = 0.31438460229587495
        sum de = 0.0004912658954562357  
    Info: cfl dt = 0.010430975181113323 cfl multiplier : 0.9420576131687243        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    8.9933e+04    |        6120 |   6.805e-02   |   20 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 535.0650646993776 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.04659264314027718, dt = 0.010430975181113323 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1874.00 ns (0.6%)
       patch tree reduce : 581.00 ns  (0.2%)
       gen split merge   : 471.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 411.00 ns  (0.1%)
       LB compute        : 307.46 us  (97.7%)
       LB move op cnt    : 0
       LB apply          : 1072.00 ns (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1692.00 ns (66.5%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4483660130718952  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 3.405816618081674e-09, max = 4.291085486000014e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (2.6130656266759396e-18,-8.038873388460927e-18,0.0002896666647060651)
        sum a = (5.3219853979545236e-17,-7.658911013459454e-19,0.005074042169531997)
        sum e = 0.31439017751077075
        sum de = 0.0005310720353438918  
    Info: cfl dt = 0.010640242990136689 cfl multiplier : 0.9613717421124829        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1368e+05    |        6120 |   5.383e-02   |   25 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 697.5540587200225 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.0570236183213905, dt = 0.010640242990136689 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.08 us    (0.7%)
       patch tree reduce : 391.00 ns  (0.1%)
       gen split merge   : 441.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 411.00 ns  (0.1%)
       LB compute        : 309.53 us  (97.8%)
       LB move op cnt    : 0
       LB apply          : 801.00 ns  (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1633.00 ns (71.2%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4483660130718952  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 6.124547504410652e-10, max = 2.9116102549298296e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (3.323924987345019e-18,3.89885359340355e-18,0.00034364138817451)
        sum a = (5.649192666344223e-17,-3.43724641055052e-18,0.0050706729699212276)
        sum e = 0.3143962517375111
        sum de = 0.0005501730733550044  
    Info: cfl dt = 0.010583003685891918 cfl multiplier : 0.9742478280749886        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1184e+05    |        6120 |   5.472e-02   |   24 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 699.9843640925446 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.06766386131152718, dt = 0.010583003685891918 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1994.00 ns (0.6%)
       patch tree reduce : 832.00 ns  (0.3%)
       gen split merge   : 481.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 471.00 ns  (0.1%)
       LB compute        : 319.30 us  (97.5%)
       LB move op cnt    : 0
       LB apply          : 1113.00 ns (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1663.00 ns (73.8%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4460784313725488  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.5824263963789616e-10, max = 1.7626187500316622e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (3.93951898808346e-18,-1.535424817196037e-17,0.0003972864143538683)
        sum a = (3.726897067328503e-17,-8.11989015932901e-18,0.005066752443936437)
        sum e = 0.31440241760719223
        sum de = 0.0005615715602513876  
    Info: cfl dt = 0.010635095941600734 cfl multiplier : 0.9828318853833258        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1342e+05    |        6120 |   5.396e-02   |   25 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 706.1010620222519 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.0782468649974191, dt = 0.010635095941600734 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1793.00 ns (0.6%)
       patch tree reduce : 461.00 ns  (0.2%)
       gen split merge   : 411.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 471.00 ns  (0.2%)
       LB compute        : 287.25 us  (97.6%)
       LB move op cnt    : 0
       LB apply          : 992.00 ns  (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1704.00 ns (72.4%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4477124183006533  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.063013287428339e-09, max = 6.683179663726466e-09
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (4.231948708513313e-18,-2.4036231431498173e-17,0.0004511510672369986)
        sum a = (5.672806856922826e-17,-1.2727169470090679e-17,0.005062240947242886)
        sum e = 0.3144087119423163
        sum de = 0.0005739543750557096  
    Info: cfl dt = 0.01065239461758592 cfl multiplier : 0.9885545902555505         [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1486e+05    |        6120 |   5.328e-02   |   25 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 718.5315699452746 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.08888196093901984, dt = 0.01065239461758592 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.03 us    (0.6%)
       patch tree reduce : 401.00 ns  (0.1%)
       gen split merge   : 420.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 411.00 ns  (0.1%)
       LB compute        : 341.14 us  (97.9%)
       LB move op cnt    : 0
       LB apply          : 932.00 ns  (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1562.00 ns (70.5%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4452614379084965  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.3014687575276834e-10, max = 6.215082073176272e-09
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (4.945320217116286e-18,-6.3105156099418285e-18,0.0005050520653562439)
        sum a = (5.862348418535131e-17,-2.6465164465081974e-17,0.005057148148467414)
        sum e = 0.3144151462463684
        sum de = 0.0005908429305552631  
    Info: cfl dt = 0.010647033142926742 cfl multiplier : 0.9923697268370336        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1397e+05    |        6120 |   5.370e-02   |   25 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 714.1332239017669 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.09953435555660577, dt = 0.00046564444339423916 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1994.00 ns (0.7%)
       patch tree reduce : 391.00 ns  (0.1%)
       gen split merge   : 421.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 391.00 ns  (0.1%)
       LB compute        : 298.67 us  (97.6%)
       LB move op cnt    : 0
       LB apply          : 1062.00 ns (0.3%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1623.00 ns (71.7%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4452614379084965  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.070497074119593e-11, max = 7.460773316977103e-07
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (4.9810398205513415e-18,-1.812765949097939e-17,0.0005073797730398668)
        sum a = (5.162966433739031e-17,-7.352428965524382e-18,0.005056912438152854)
        sum e = 0.3144144614858832
        sum de = 0.0005914932822185223  
    Info: cfl dt = 0.010671519169061264 cfl multiplier : 0.9949131512246892        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    9.6002e+04    |        6120 |   6.375e-02   |   37 % |   0 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 26.2958153778011 (tsim/hr)                              [sph::Model][rank=0] 
    Info: iteration since start : 14                                                      [SPH][rank=0] 
    Info: time since start : 9.048234485 (s)                                              [SPH][rank=0] 
    Info: dump to _to_trash/dump_0001.vtk                                            [VTK Dump][rank=0]
                  - took 2.76 ms, bandwidth = 177.73 MB/s  
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed





.. rst-class:: sphx-glr-timing

   **Total running time of the script:** (0 minutes 2.226 seconds)

**Estimated memory usage:**  79 MB


.. _sphx_glr_download__as_gen_run_sph_shear_test.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: run_sph_shear_test.ipynb <run_sph_shear_test.ipynb>`

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: run_sph_shear_test.py <run_sph_shear_test.py>`

    .. container:: sphx-glr-download sphx-glr-download-zip

      :download:`Download zipped: run_sph_shear_test.zip <run_sph_shear_test.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
